package com.jiheng.formservice.form.controller;


import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.jiheng.formservice.common.entity.R;
import com.jiheng.formservice.form.entity.vo.QueryTemplateReqVO;
import com.jiheng.formservice.form.entity.vo.SaveOrUpdateTemplateReqVO;
import com.jiheng.formservice.form.entity.vo.TemplateDetailResVO;
import com.jiheng.formservice.form.service.TemplateService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * <p>
 * 表单模板表 前端控制器
 * </p>
 *
 * @author guoj
 * @since 2021-11-16
 */
@RestController
@Api(tags = "表单管理")
@RequestMapping("/form/template")
public class TemplateController {

    @Autowired
    private TemplateService templateService;

    /**
     * 表单模板新增or编辑接口，header中传入userId
     * templateName 唯一
     */
    @PostMapping("/saveOrUpdateTemplate")
    @ApiOperation(value = "新增/修改表单信息", notes = "新增/修改表单信息")
    public R<Boolean> saveOrUpdateBuilding(@RequestBody @Valid SaveOrUpdateTemplateReqVO param) {
        boolean isOk = templateService.checkOutName(param);
        if (isOk){
            templateService.saveOrUpdateBuilding(param);
            return R.success("新增/修改楼栋或楼层成功");
        }else {
            return R.success("表单模板名称重复，操作失败");
        }

    }
    /**
     * 表单模板详情接口，逻辑删除的正常返回显示
     */
    @PostMapping("/queryTemplateDetail/{id}")
    @ApiOperation(value = "查看模板详情", notes = "查看模板详情,逻辑删除正常返回")
    public R<TemplateDetailResVO> queryTemplateDetail(@PathVariable Long id) {
        return R.success(templateService.queryTemplateDetail(id));
    }

    /**
     * 表单模板删除接口
     */
    @PostMapping("/deleteTemplate/{}")
    @ApiOperation(value = "删除表单模板", notes = "删除表单模板")
    public R<String> deleteTemplate(@PathVariable Long id) {
        templateService.deleteTemplate(id);
        return R.success("删除表单模板成功");
    }

    /**
     * 表单模板批量删除接口
     */
    @PostMapping("/deleteTemplateBatch")
    @ApiOperation(value = "查看模板详情", notes = "查看模板详情,逻辑删除正常返回")
    public R<String> deleteTemplateBatch(@RequestBody List<Long> ids) {
        ids.forEach(id -> templateService.deleteTemplate(id));
        return  R.success("批量删除表单模板成功");
    }
    /**
     * 表单模板列表接口，带分页
     */
    @PostMapping("/queryTemplateByPage")
    @ApiOperation(value = "查看模板详情", notes = "查看模板详情,逻辑删除正常返回")
    public R<Page<TemplateDetailResVO>> queryTemplateList(@RequestBody @Valid QueryTemplateReqVO param) {
        return R.success(templateService.queryTemplateByPage(param));
    }

}
