package com.jiheng.formservice.form.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.jiheng.formservice.common.context.BaseContextHandler;
import com.jiheng.formservice.common.utils.DozerUtils;
import com.jiheng.formservice.form.entity.Template;
import com.jiheng.formservice.form.entity.vo.QueryTemplateReqVO;
import com.jiheng.formservice.form.entity.vo.SaveOrUpdateTemplateReqVO;
import com.jiheng.formservice.form.entity.vo.TemplateDetailResVO;
import com.jiheng.formservice.form.mapper.TemplateMapper;
import com.jiheng.formservice.form.service.TemplateService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * <p>
 * 表单模板表 服务实现类
 * </p>
 *
 * @author guoj
 * @since 2021-11-16
 */
@Service
public class TemplateServiceImpl extends ServiceImpl<TemplateMapper, Template> implements TemplateService {

    @Autowired
    TemplateMapper templateMapper;
    @Autowired
    DozerUtils dozerUtils;
    /**
     * 校验名称重复
     * @param param
     * @return
     */
    @Override
    public boolean checkOutName(SaveOrUpdateTemplateReqVO param) {
        QueryWrapper<Template> queryWrapper = new QueryWrapper();
        queryWrapper.eq("template_name",param.getTemplateName());
        if (param.getId() != null){
            queryWrapper.ne("id",param.getId());
        }

        List<Template> templates = this.list(queryWrapper);
        if (templates !=null && templates.size() > 0){
            return false;
        }else {
            return true;
        }
    }

    /**
     * 新增or编辑
     * @param param
     */
    @Override
    public void saveOrUpdateBuilding(SaveOrUpdateTemplateReqVO param) {
        Template map = dozerUtils.map(param, Template.class);
        //存放租户id
        map.setTenant(BaseContextHandler.getTenant());
        this.saveOrUpdate(map);
    }

    /**
     * 查看详情
     * @param id
     * @return
     */
    @Override
    public TemplateDetailResVO queryTemplateDetail(Long id) {
        QueryWrapper<Template> queryWrapper = new QueryWrapper();
        queryWrapper.eq("id",id);
        queryWrapper.in("is_delete",1,0);
        return dozerUtils.map(this.getOne(queryWrapper),TemplateDetailResVO.class);
    }

    @Override
    public void deleteTemplate(Long id) {
        this.removeById(id);
    }

    @Override
    public Page<TemplateDetailResVO> queryTemplateByPage(QueryTemplateReqVO param) {
        Page<TemplateDetailResVO> page = new Page<>(param.getPageIndex(), param.getPageSize());
        //存放租户id
        param.setTenant(BaseContextHandler.getTenant());
        List<TemplateDetailResVO> list = templateMapper.queryTemplateByPage(page,param);
        page.setRecords(list);
        return page;
    }
}
