package com.jiheng.formservice.framework.config;

import com.github.xiaoymin.knife4j.spring.annotations.EnableKnife4j;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.web.context.WebServerInitializedEvent;
import org.springframework.context.ApplicationListener;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Import;
import springfox.bean.validators.configuration.BeanValidatorPluginsConfiguration;
import springfox.documentation.builders.ApiInfoBuilder;
import springfox.documentation.builders.PathSelectors;
import springfox.documentation.builders.RequestHandlerSelectors;
import springfox.documentation.builders.RequestParameterBuilder;
import springfox.documentation.service.ApiInfo;
import springfox.documentation.service.ParameterType;
import springfox.documentation.service.RequestParameter;
import springfox.documentation.spi.DocumentationType;
import springfox.documentation.spring.web.plugins.Docket;
import springfox.documentation.swagger2.annotations.EnableSwagger2;

import java.net.Inet4Address;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.List;

/**
 * Knife4j配置
 */
@Slf4j
@Configuration
@EnableSwagger2
@EnableKnife4j
@Import(BeanValidatorPluginsConfiguration.class)
public class Knife4jConfig implements ApplicationListener<WebServerInitializedEvent> {

    private boolean isOpen = true;


    @Bean(value = "auth4Knife")
    public Docket auth4Knife() {
        return new Docket(DocumentationType.SWAGGER_2)
                .enable(isOpen)
                .useDefaultResponseMessages(false)
                .apiInfo(apiInfo())
                .groupName("表单服务")
                .select()
                .apis(RequestHandlerSelectors.basePackage("com.jiheng.formservice.form.controller"))
                .paths(PathSelectors.any())
                .build();
    }

    private List<RequestParameter> parameterList() {
    	 List<RequestParameter> parameterList = new ArrayList<>();
    	 RequestParameterBuilder tokenBuilder = new RequestParameterBuilder();
    	 tokenBuilder
    	 .name("Authorization")
    	 .in(ParameterType.HEADER)
    	 .description("用户登录token")
    	 .required(false);
         parameterList.add(tokenBuilder.build());
        return  parameterList;
    }

    private ApiInfo apiInfo() {
        return new ApiInfoBuilder()
                .title("form")
                .build();
    }
   
   
    @Override
    public void onApplicationEvent(WebServerInitializedEvent event) {
    	 try {
             //获取IP
             InetAddress localHost = Inet4Address.getLocalHost();
             String hostAddress = localHost.getHostAddress();
             //获取端口号
             int port = event.getWebServer().getPort();
             //获取应用名
             String applicationName = event.getApplicationContext().getApplicationName();
             log.info("项目启动启动成功！接口文档地址: http://" + hostAddress + ":" + port + applicationName + "/doc.html");
         } catch (UnknownHostException e) {
             e.printStackTrace();
         }
    }
}